import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-C8ZMxon6.js";import{a as u,b as d,j as i,u as n,ad as m,ac as l,e as f,aN as _}from"./jwt-decode.esm-WxnsjcWa.js";import{u as b}from"./workspaceStore-BPoH18ml.js";import"./OTPInput-Djs3Ydr-.js";import"./Logo-BVLFeEnD.js";import"./string-CLwgGjmi.js";import"./CircularLoading-DUNzRLAG.js";import"./index-jwcqzWAF.js";import"./userStore-DqVsq5a9.js";import"./url-D3_feX5J.js";import"./colorHelpers-e-FBNmOl.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="902b6661-59de-4e33-bf3e-eee85680f263",e._sentryDebugIdIdentifier="sentry-dbid-902b6661-59de-4e33-bf3e-eee85680f263")}catch{}})();const g={class:"runner"},y=u({__name:"Login",setup(e){const o=m(),r=l(),t=b(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),d("div",g,[i(p,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),L=_(y,[["__scopeId","data-v-12c690e1"]]);export{L as default};
//# sourceMappingURL=Login-BbAZaVh3.js.map
