import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-BUh2qFva.js";import{a as i,ac as s,p as m,e as a,u as c}from"./jwt-decode.esm-WxnsjcWa.js";import"./router-845TlMat.js";import"./ts.worker-B_U1Chmr.js";import"./fetch-CKbNFAbp.js";import"./record-CLwbBMc2.js";import"./SaveButton-Bo5VPeK_.js";import"./ExclamationCircleOutlined-Bh0sR1-k.js";import"./CrudView-9z4hCmZC.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BfsR1yOB.js";import"./constants-_UgM3BkR.js";import"./url-D3_feX5J.js";import"./PhDotsThreeVertical.vue-DbKuNIoU.js";import"./index-Bvc2mrwp.js";import"./asyncComputed-D4eSsgb3.js";import"./omniChatStore-BQygA5Oz.js";import"./uuid-Cd1ehmhB.js";import"./PhCopySimple.vue-Cjod2F4I.js";import"./PhPencil.vue-DZeFxmyQ.js";import"./useCodebaseEvents-U6B1OrKX.js";import"./contracts.generated-BdL2n5GU.js";import"./index-jwcqzWAF.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="8e5f0275-6f31-46cc-847e-58615d18fd61",o._sentryDebugIdIdentifier="sentry-dbid-8e5f0275-6f31-46cc-847e-58615d18fd61")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(d,f)=>(a(),m(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-B1QRmVje.js.map
