import{P as g}from"./PlayerNavbar-g8lSZdK6.js";import{a as _,ac as c,r as h,c as b,b as y,p as k,g as v,h as w,u as n,j as L,a4 as C,ad as N,e as i,aN as I}from"./jwt-decode.esm-WxnsjcWa.js";import{u as V}from"./workspaceStore-BPoH18ml.js";import"./userStore-DqVsq5a9.js";import"./metadata-BdPWnUnX.js";import"./PhMagnifyingGlass.vue-BAMmmnug.js";import"./PhWebhooksLogo.vue-k1TZX4Vv.js";import"./LoadingOutlined-Bhephp-k.js";import"./PhSignOut.vue-Cz3Q18bM.js";import"./index-CrKYrM9C.js";import"./url-D3_feX5J.js";import"./colorHelpers-e-FBNmOl.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="f5a47c39-1710-40b2-8cd3-fec0ec0f73fb",o._sentryDebugIdIdentifier="sentry-dbid-f5a47c39-1710-40b2-8cd3-fec0ec0f73fb")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(o){const e=N(),t=V(),u=c().path,a=h(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},f=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=C("RouterView");return i(),y("div",B,[n(t).state.workspace?(i(),k(g,{key:0,"current-path":n(u),"hide-login":f.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(m)])])}}}),G=I(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-B497RvQ-.js.map
